from django.test import TestCase, RequestFactory
from django.contrib.sites.models import Site

from .models import KeybaseVerification
from .views import KeybaseVerificationView

class KeybaseVerificationTestCase(TestCase):
    def setUp(self):
        self.factory = RequestFactory()
        # Create Site and KeybaseVerification model to test with
        self.site = Site.objects.create(domain='testserver')
        self.kbv = KeybaseVerification.objects.create(site=self.site, data='Test client Keybase Verification')

    def test_base_text_file(self):
        # Request and Response for the Keybase Verification url
        request = self.factory.get('/keybase.txt')
        response = KeybaseVerificationView.as_view()(request)

        # Assert the status code is 200 and the content is the same as created
        self.assertEqual(response.status_code, 200)
        self.assertEqual(response.content.decode(), 'Test client Keybase Verification')

    def test_well_known_text_file(self):
        # Request and Response for the Keybase Verification url
        request = self.factory.get('/.well-known/keybase.txt')
        response = KeybaseVerificationView.as_view()(request)

        # Assert the status code is 200 and the content is the same as created
        self.assertEqual(response.status_code, 200)
        self.assertEqual(response.content.decode(), 'Test client Keybase Verification')



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-21 21:07
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
    ]

    operations = [
        migrations.CreateModel(
            name='KeybaseVerification',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('data', models.TextField(blank=True, null=True)),
                ('site', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to='sites.Site')),
            ],
            options={
                'verbose_name': 'Keybase Verification',
                'verbose_name_plural': 'Keybase Verification',
            },
        ),
    ]



from django.http import HttpResponse
from django.shortcuts import get_object_or_404
from django.views import View
from django.contrib.sites.shortcuts import get_current_site

from keybase_verification.models import KeybaseVerification


class KeybaseVerificationView(View):
    def get(self, request):
        site = get_current_site(request)
        kbv = get_object_or_404(KeybaseVerification, site=site)
        return HttpResponse(kbv.data, content_type='text/plain')



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-21 21:10
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('keybaseverification', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='keybaseverification',
            name='data',
            field=models.TextField(blank=True, help_text='Get this by visiting http://keybase.io', null=True),
        ),
    ]



from django.db import models
from django.contrib.sites.models import Site


class KeybaseVerification(models.Model):
    site = models.OneToOneField(Site, on_delete=models.CASCADE)
    data = models.TextField(blank=True, null=True, help_text="Get this by visiting http://keybase.io")

    def __str__(self):
        return 'Keybase Verification for {}'.format(self.site.domain)

    class Meta:
        verbose_name = 'Keybase Verification'
        verbose_name_plural = 'Keybase Verification'



from django.conf.urls import url
from keybase_verification.views import KeybaseVerificationView


urlpatterns = [
    url(r'^keybase.txt', KeybaseVerificationView.as_view()),
    url(r'^.well-known/keybase.txt', KeybaseVerificationView.as_view()),
]
